import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_apigateway._jsii
import aws_cdk.aws_apigatewayv2._jsii
import aws_cdk.aws_ec2._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_rds._jsii
import aws_cdk.aws_secretsmanager._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "cdk-serverless-lamp",
    "1.4.14",
    __name__[0:-6],
    "cdk-serverless-lamp@1.4.14.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
